#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dbus-hslogger
version:              0.1.0.1
visibility:           public
id:                   dbus-hslogger-0.1.0.1-4QAi5DjDpP9FnuYY3vgyTR
key:                  dbus-hslogger-0.1.0.1-4QAi5DjDpP9FnuYY3vgyTR
license:              BSD-3-Clause
copyright:            Ivan Malison
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/IvanMalison/dbus-hslogger#readme
synopsis:             Expose a dbus server to control hslogger
description:
    Please see the README on Github at <https://github.com/IvanMalison/dbus-hslogger#readme>

category:             System
abi:                  c1fe9937dc929f1e22eb076d40b4c408
exposed:              True
exposed-modules:      System.Log.DBus.Client System.Log.DBus.Server
hidden-modules:       Paths_dbus_hslogger
import-dirs:          /usr/lib/ghc-9.6.6/site-local/dbus-hslogger-0.1.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dbus-hslogger-0.1.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dbus-hslogger-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dbus-hslogger
hs-libraries:         HSdbus-hslogger-0.1.0.1-4QAi5DjDpP9FnuYY3vgyTR
depends:
    base-4.18.2.1 dbus-1.3.3-7WocnastLVg8XCFemq4uC7
    hslogger-1.3.2.0-L3L5i9xDKit4ZAoE0QOqgA

haddock-interfaces:
    /usr/share/doc/haskell-dbus-hslogger/html/dbus-hslogger.haddock

haddock-html:         /usr/share/doc/haskell-dbus-hslogger/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

